==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/lv/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Lietotājs var pieslēgties sistēmai',
    'activated_disabled_help_text' => 'Jūs nevarat rediģēt sava konta aktivizācijas statusu.',
    'assets_user'       => 'Aktīvi, kas piešķirti: nosaukums',
    'bulk_update_warn'	=> 'Jūs gatavojaties rediģēt lietotāju: user_count īpašības. Lūdzu, ņemiet vērā, ka jūs nevarat mainīt savus lietotāja atribūtus, izmantojot šo veidlapu, un tie ir jārediģē savam lietotājam atsevišķi.',
    'bulk_update_help'	=> 'Šī veidlapa ļauj vienlaikus atjaunināt vairākus lietotājus. Aizpildiet tikai nepieciešamos laukus. Jebkurš tukšs laukums paliek nemainīgs.',
    'current_assets'    => 'Aktīvi, kas pašlaik tiek pārbaudīti šim lietotājam',
    'clone'             => 'Klons lietotājs',
    'contact_user'      => 'Kontaktpersona: vārds',
    'edit'              => 'Rediģēt lietotāju',
    'filetype_info'     => 'Atļautie failu tipi ir png, gif, jpg, jpeg, doc, docx, pdf, txt, zip un rar.',
    'history_user'      => 'Vēsture: vārds',
	'info'				=> 'Info',
    'restore_user'		=> 'Noklikšķiniet šeit, lai tos atjaunotu.',
    'last_login'        => 'Pēdējais pieteikšanās',
    'ldap_config_text'  => 'LDAP konfigurācijas iestatījumus var atrast Admin> Settings. Atlasītā atrašanās vieta (izvēles) tiks iestatīta visiem importētajiem lietotājiem.',
    'print_assigned'    => 'Drukāt izsniegto',
    'software_user'     => 'Programmatūra Pārbaudīta: nosaukums',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Apskatīt Lietotāju: vārds',
    'usercsv'           => 'CSV fails',
    'two_factor_admin_optin_help' => 'Jūsu pašreizējie administrēšanas iestatījumi ļauj atlasīt divu faktoru autentifikāciju.',
    'two_factor_enrolled' => 'Reģistrēta 2F ierīce',
    'two_factor_active'   => '2FA aktīvs',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/lv/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Lietotājs var pieslēgties sistēmai',
    'activated_disabled_help_text' => 'Jūs nevarat rediģēt sava konta aktivizācijas statusu.',
    'assets_user'       => 'Aktīvi, kas piešķirti: nosaukums',
    'bulk_update_warn'	=> 'Jūs gatavojaties rediģēt lietotāju: user_count īpašības. Lūdzu, ņemiet vērā, ka jūs nevarat mainīt savus lietotāja atribūtus, izmantojot šo veidlapu, un tie ir jārediģē savam lietotājam atsevišķi.',
    'bulk_update_help'	=> 'Šī veidlapa ļauj vienlaikus atjaunināt vairākus lietotājus. Aizpildiet tikai nepieciešamos laukus. Jebkurš tukšs laukums paliek nemainīgs.',
    'current_assets'    => 'Aktīvi, kas pašlaik tiek pārbaudīti šim lietotājam',
    'clone'             => 'Klons lietotājs',
    'contact_user'      => 'Kontaktpersona: vārds',
    'edit'              => 'Rediģēt lietotāju',
    'filetype_info'     => 'Atļautie failu tipi ir png, gif, jpg, jpeg, doc, docx, pdf, txt, zip un rar.',
    'history_user'      => 'Vēsture: vārds',
    'info'				=> 'Info',
    'restore_user'		=> 'Noklikšķiniet šeit, lai tos atjaunotu.',
    'last_login'        => 'Pēdējais pieteikšanās',
    'ldap_config_text'  => 'LDAP konfigurācijas iestatījumus var atrast Admin> Settings. Atlasītā atrašanās vieta (izvēles) tiks iestatīta visiem importētajiem lietotājiem.',
    'print_assigned'    => 'Drukāt izsniegto',
    'software_user'     => 'Programmatūra Pārbaudīta: nosaukums',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Apskatīt Lietotāju: vārds',
    'usercsv'           => 'CSV fails',
    'two_factor_admin_optin_help' => 'Jūsu pašreizējie administrēšanas iestatījumi ļauj atlasīt divu faktoru autentifikāciju.',
    'two_factor_enrolled' => 'Reģistrēta 2F ierīce',
    'two_factor_active'   => '2FA aktīvs',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
